colour.optimal Package — Colour 0.3.0 documentation

# colour.optimal Package

## Sub-Packages

- colour.optimal.dataset Package
  - Sub-Modules
    - colour.optimal.dataset.optimal_colour_stimuli Module
      - Optimal Colour Stimuli
  - Module Contents

## Sub-Modules

- colour.optimal.macadam_limits Module
  - Optimal Colour Stimuli - MacAdam Limits

## Module Contents

`colour.optimal.` `is_within_macadam_limits`(xyY, illuminant)

  Returns if given CIE xyY colourspace matrix is within MacAdam limits of given illuminant.

  Parameters: | xyY (array_like, (3,)) – CIE xyY colourspace matrix. illuminant (unicode) – Illuminant.
  Returns: | Is within MacAdam limits.
  Return type: | bool

  Notes

  - Input CIE xyY colourspace matrix is in domain [0, 1].
  - This definition requires scipy to be installed.

  Examples

      >>> is_within_macadam_limits((0.3205, 0.4131, 0.51), 'A')
      True
      >>> is_within_macadam_limits((0.0005, 0.0031, 0.001), 'A')
      False